<?php
/*
Plugin Name: Hobbybrauer IBU Rechner
Plugin URI: https://www.brauerbund.org
Description: Ein Plugin, das die Bitterkeitseinheiten beim Bierbrauen berechnet.
Version: 1.0
Author: Marcus Eickert
Author URI: https://www.brauerbund.org
License: Proprietary
*/

// Include the license checking class
include_once('license_checker.php');  

// Create a new instance of the license checker class
$ibulicenseChecker = new ibuLicenseChecker();


// Fge JavaScript und CSS hinzu
add_action('wp_enqueue_scripts', 'ibu_rechner_enqueue_scripts');

function ibu_rechner_enqueue_scripts() {
    wp_enqueue_style('ibu-rechner-style', plugins_url('style.css', __FILE__));
    wp_enqueue_script('ibu-rechner-script', plugins_url('script.js', __FILE__), array('jquery'), '1.0', true);
}

// Erstelle einen Shortcode fr den Tinseth IBU-Rechner
add_shortcode('ibu_rechner', 'ibu_rechner_shortcode');

function ibu_rechner_shortcode() {
     global $ibulicenseChecker;  // Access the global license checker instance

    ob_start();

   // Perform license check and handle submission of license form
    if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['license_code'])) {
        $valid_ibulicense = $ibulicenseChecker->check_license($_POST['license_code']);
    } else {
        $valid_ibulicense = $ibulicenseChecker->check_license();
    }

    if (!$valid_ibulicense) {

        ?>
        Bitte geben Sie eine Lizenznummer ein:
        <form action="" method="POST">
            <input type="text" name="license_code" required>
            <input type="submit" value="&Uuml;berpr&uuml;fen">
        </form>
        <?php
    } else {
        ?>
        <div id="tinseth-ibu-rechner">
            <form id="ibu-rechner-form" method="post">
                <label for="hopfenmenge">Hopfenmenge (in Gramm):</label>
                <input type="text" name="hopfenmenge" id="hopfenmenge" required>

                <label for="alphasaeuregehalt">Alpha-S&auml;uregehalt (%):</label>
                <input type="text" name="alphasaeuregehalt" id="alphasaeuregehalt" required>

                <label for="wuerzemenge">W&uuml;rzemenge (in Liter):</label>
                <input type="text" name="wuerzemenge" id="wuerzemenge" required>

                <label for="kochdauer">Kochdauer (in Minuten):</label>
                <input type="text" name="kochdauer" id="kochdauer" required>

                <input type="submit" value="Berechnen">
            </form>

            <div id="ibu-rechner-ergebnis"></div>
        </div>
        <?php
    }
    return ob_get_clean();
}

// Fge die JavaScript-Funktion hinzu, um die IBU nach Tinseth zu berechnen
add_action('wp_footer', 'ibu_rechner_js');

function ibu_rechner_js() {
    ?>
    <script>
        jQuery(document).ready(function($) {
            $('#ibu-rechner-form').on('submit', function(e) {
                e.preventDefault();

                var hopfenMenge = parseFloat($('#hopfenmenge').val().replace(',', '.'));
                var alphaSaeuregehalt = parseFloat($('#alphasaeuregehalt').val().replace(',', '.'));
                var wuerzeMenge = parseFloat($('#wuerzemenge').val().replace(',', '.'));
                var kochDauer = parseFloat($('#kochdauer').val().replace(',', '.'));

                if (isNaN(hopfenMenge) || isNaN(alphaSaeuregehalt) || isNaN(wuerzeMenge) || isNaN(kochDauer) || hopfenMenge <= 0 || alphaSaeuregehalt <= 0 || wuerzeMenge <= 0 || kochDauer <= 0) {
                    $('#ibu-rechner-ergebnis').html('<p class="error">Ung&uuml;ltige Eingabe. Bitte &uuml;berpr&uuml;fe deine Angaben.</p>');
                } else {
                    var ibu = (hopfenMenge * alphaSaeuregehalt * 10 / wuerzeMenge * (1 - Math.exp(-0.04 * kochDauer))).toFixed(2);
                    $('#ibu-rechner-ergebnis').html('<p>Die Bitterkeitseinheiten (IBU) nach Tinseth betragen ' + ibu + '.</p>');
                }
            });
        });
    </script>
    <?php
}
